<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Slider;
use Illuminate\Http\Request;

class SlidersController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = Slider::latest()->get();
        return view('admin.sliders.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.sliders.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'title_ar' => 'required',
            'title_en' => 'required',
            'note_ar' => 'required',
            'note_en' => 'required',
            'image' => 'required|image'
        ]);
        $slider = new Slider();
        $slider['title->ar'] = $request['title_ar'];
        $slider['title->en'] = $request['title_en'];
        $slider['note->ar'] = $request['note_ar'];
        $slider['note->en'] = $request['note_en'];

        if ($request->hasFile('image')) {
            $slider->setImageAttribute();
        }
        $slider->save();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('sliders.index');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = Slider::find($id);
        return view('admin.sliders.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'title_ar' => 'required',
            'title_en' => 'required',
            'note_ar' => 'required',
            'note_en' => 'required',
            'image' => 'nullable|image'
        ]);
        $slider = Slider::find($id);
        $slider['title->ar'] = $request['title_ar'];
        $slider['title->en'] = $request['title_en'];
        $slider['note->ar'] = $request['note_ar'];
        $slider['note->en'] = $request['note_en'];
        if ($request->hasFile('image')) {
            $slider->setImageAttribute();
        }
        $slider->update();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('sliders.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $slider = Slider::find($id);
        $slider->delete();
        toast('تمت العملية بنجاح', 'success', 'left');
        return back();
    }
}



